class ForkName:
    Frontier = "Frontier"
    Homestead = "Homestead"
    EIP150 = "EIP150"
    EIP158 = "EIP158"
    Byzantium = "Byzantium"
    Constantinople = "Constantinople"
    Metropolis = "Metropolis"
    ConstantinopleFix = "ConstantinopleFix"
    Istanbul = "Istanbul"
    Berlin = "Berlin"
    London = "London"
    ArrowGlacier = "ArrowGlacier"
    GrayGlacier = "GrayGlacier"
    Paris = "Paris"
    Shanghai = "Shanghai"
    Cancun = "Cancun"
